import { PrinterAddCutType, PrinterErrorResult, PrinterErrorCodeResult, PrinterModelLang, CommonParams, ColorType, TextLangType } from './common';
import { PrinterGetSettingsType, GetPrinterSettingsDensityValues, GetPrinterSettingsPaperWidthValues, GetPrinterSettingsPrintSpeedValues } from './settings';
import { PrinterPaperStatus, PrinterPanelSwitchStatus, PrinterDrawerStatus, PrinterErrorStatus, PrinterAutoRecoverErrorStatus, PrinterBatteryLevelStatus, PrinterRemovalWaitingStatus, PrinterPaperTakenSensorStatus, PrinterUnrecoverErrorStatus } from './status';
import { ImageCompressType, ImageHalftoneType, ImageColorModeType } from './image';
import { BarcodeType, BarcodeHRI } from './barcode';
import { SymbolType, SymbolLevel } from './symbol';
import { FontType, TextAlignType } from './textStyle';
import { PrinterAddPulseDrawerType, PrinterAddPulseTimeType } from './pulse';
export declare const PrinterConstants: {
    readonly [x: number]: string;
    readonly PARAM_DEFAULT: CommonParams.PARAM_DEFAULT;
    readonly PARAM_UNSPECIFIED: CommonParams.PARAM_UNSPECIFIED;
    readonly TRUE: CommonParams.TRUE;
    readonly FALSE: CommonParams.FALSE;
    readonly UNKNOWN: CommonParams.UNKNOWN;
    readonly LANG_EN: TextLangType.LANG_EN;
    readonly LANG_JA: TextLangType.LANG_JA;
    readonly LANG_ZH_CN: TextLangType.LANG_ZH_CN;
    readonly LANG_ZH_TW: TextLangType.LANG_ZH_TW;
    readonly LANG_KO: TextLangType.LANG_KO;
    readonly LANG_TH: TextLangType.LANG_TH;
    readonly LANG_VI: TextLangType.LANG_VI;
    readonly LANG_MULTI: TextLangType.LANG_MULTI;
    readonly HIGH_VOLTAGE_ERR: PrinterUnrecoverErrorStatus.HIGH_VOLTAGE_ERR;
    readonly LOW_VOLTAGE_ERR: PrinterUnrecoverErrorStatus.LOW_VOLTAGE_ERR;
    readonly REMOVAL_DETECT_PAPER: PrinterPaperTakenSensorStatus.REMOVAL_DETECT_PAPER;
    readonly REMOVAL_DETECT_PAPER_NONE: PrinterPaperTakenSensorStatus.REMOVAL_DETECT_PAPER_NONE;
    readonly REMOVAL_DETECT_UNKNOWN: PrinterPaperTakenSensorStatus.REMOVAL_DETECT_UNKNOWN;
    readonly REMOVAL_WAIT_PAPER: PrinterRemovalWaitingStatus.REMOVAL_WAIT_PAPER;
    readonly REMOVAL_WAIT_NONE: PrinterRemovalWaitingStatus.REMOVAL_WAIT_NONE;
    readonly EPOS2_BATTERY_LEVEL_6: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_6;
    readonly EPOS2_BATTERY_LEVEL_5: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_5;
    readonly EPOS2_BATTERY_LEVEL_4: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_4;
    readonly EPOS2_BATTERY_LEVEL_3: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_3;
    readonly EPOS2_BATTERY_LEVEL_2: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_2;
    readonly EPOS2_BATTERY_LEVEL_1: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_1;
    readonly EPOS2_BATTERY_LEVEL_0: PrinterBatteryLevelStatus.EPOS2_BATTERY_LEVEL_0;
    readonly HEAD_OVERHEAT: PrinterAutoRecoverErrorStatus.HEAD_OVERHEAT;
    readonly MOTOR_OVERHEAT: PrinterAutoRecoverErrorStatus.MOTOR_OVERHEAT;
    readonly BATTERY_OVERHEAT: PrinterAutoRecoverErrorStatus.BATTERY_OVERHEAT;
    readonly WRONG_PAPER: PrinterAutoRecoverErrorStatus.WRONG_PAPER;
    readonly COVER_OPEN: PrinterAutoRecoverErrorStatus.COVER_OPEN;
    readonly NO_ERR: PrinterErrorStatus.NO_ERR;
    readonly MECHANICAL_ERR: PrinterErrorStatus.MECHANICAL_ERR;
    readonly AUTOCUTTER_ERR: PrinterErrorStatus.AUTOCUTTER_ERR;
    readonly UNRECOVER_ERR: PrinterErrorStatus.UNRECOVER_ERR;
    readonly AUTORECOVER_ERR: PrinterErrorStatus.AUTORECOVER_ERR;
    readonly DRAWER_HIGH: PrinterDrawerStatus.DRAWER_HIGH;
    readonly DRAWER_LOW: PrinterDrawerStatus.DRAWER_LOW;
    readonly SWITCH_ON: PrinterPanelSwitchStatus.SWITCH_ON;
    readonly SWITCH_OFF: PrinterPanelSwitchStatus.SWITCH_OFF;
    readonly PAPER_OK: PrinterPaperStatus.PAPER_OK;
    readonly PAPER_NEAR_END: PrinterPaperStatus.PAPER_NEAR_END;
    readonly PAPER_EMPTY: PrinterPaperStatus.PAPER_EMPTY;
    readonly ALIGN_LEFT: TextAlignType.ALIGN_LEFT;
    readonly ALIGN_CENTER: TextAlignType.ALIGN_CENTER;
    readonly ALIGN_RIGHT: TextAlignType.ALIGN_RIGHT;
    readonly PULSE_100: PrinterAddPulseTimeType.PULSE_100;
    readonly PULSE_200: PrinterAddPulseTimeType.PULSE_200;
    readonly PULSE_300: PrinterAddPulseTimeType.PULSE_300;
    readonly PULSE_400: PrinterAddPulseTimeType.PULSE_400;
    readonly PULSE_500: PrinterAddPulseTimeType.PULSE_500;
    readonly DRAWER_2PIN: PrinterAddPulseDrawerType.DRAWER_2PIN;
    readonly DRAWER_5PIN: PrinterAddPulseDrawerType.DRAWER_5PIN;
    readonly LEVEL_0: SymbolLevel.LEVEL_0;
    readonly LEVEL_1: SymbolLevel.LEVEL_1;
    readonly LEVEL_2: SymbolLevel.LEVEL_2;
    readonly LEVEL_3: SymbolLevel.LEVEL_3;
    readonly LEVEL_4: SymbolLevel.LEVEL_4;
    readonly LEVEL_5: SymbolLevel.LEVEL_5;
    readonly LEVEL_6: SymbolLevel.LEVEL_6;
    readonly LEVEL_7: SymbolLevel.LEVEL_7;
    readonly LEVEL_8: SymbolLevel.LEVEL_8;
    readonly LEVEL_L: SymbolLevel.LEVEL_L;
    readonly LEVEL_M: SymbolLevel.LEVEL_M;
    readonly LEVEL_Q: SymbolLevel.LEVEL_Q;
    readonly LEVEL_H: SymbolLevel.LEVEL_H;
    readonly SYMBOL_PDF417_STANDARD: SymbolType.SYMBOL_PDF417_STANDARD;
    readonly SYMBOL_PDF417_TRUNCATED: SymbolType.SYMBOL_PDF417_TRUNCATED;
    readonly SYMBOL_QRCODE_MODEL_1: SymbolType.SYMBOL_QRCODE_MODEL_1;
    readonly SYMBOL_QRCODE_MODEL_2: SymbolType.SYMBOL_QRCODE_MODEL_2;
    readonly SYMBOL_QRCODE_MICRO: SymbolType.SYMBOL_QRCODE_MICRO;
    readonly SYMBOL_MAXICODE_MODE_2: SymbolType.SYMBOL_MAXICODE_MODE_2;
    readonly SYMBOL_MAXICODE_MODE_3: SymbolType.SYMBOL_MAXICODE_MODE_3;
    readonly SYMBOL_MAXICODE_MODE_4: SymbolType.SYMBOL_MAXICODE_MODE_4;
    readonly SYMBOL_MAXICODE_MODE_5: SymbolType.SYMBOL_MAXICODE_MODE_5;
    readonly SYMBOL_MAXICODE_MODE_6: SymbolType.SYMBOL_MAXICODE_MODE_6;
    readonly SYMBOL_GS1_DATABAR_STACKED: SymbolType.SYMBOL_GS1_DATABAR_STACKED;
    readonly SYMBOL_GS1_DATABAR_STACKED_OMNIDIRECTIONAL: SymbolType.SYMBOL_GS1_DATABAR_STACKED_OMNIDIRECTIONAL;
    readonly SYMBOL_GS1_DATABAR_EXPANDED_STACKED: SymbolType.SYMBOL_GS1_DATABAR_EXPANDED_STACKED;
    readonly SYMBOL_AZTECCODE_FULLRANGE: SymbolType.SYMBOL_AZTECCODE_FULLRANGE;
    readonly SYMBOL_AZTECCODE_COMPACT: SymbolType.SYMBOL_AZTECCODE_COMPACT;
    readonly SYMBOL_DATAMATRIX_SQUARE: SymbolType.SYMBOL_DATAMATRIX_SQUARE;
    readonly SYMBOL_DATAMATRIX_RECTANGLE_8: SymbolType.SYMBOL_DATAMATRIX_RECTANGLE_8;
    readonly SYMBOL_DATAMATRIX_RECTANGLE_12: SymbolType.SYMBOL_DATAMATRIX_RECTANGLE_12;
    readonly SYMBOL_DATAMATRIX_RECTANGLE_16: SymbolType.SYMBOL_DATAMATRIX_RECTANGLE_16;
    readonly FONT_A: FontType.FONT_A;
    readonly FONT_B: FontType.FONT_B;
    readonly FONT_C: FontType.FONT_C;
    readonly FONT_D: FontType.FONT_D;
    readonly FONT_E: FontType.FONT_E;
    readonly HRI_NONE: BarcodeHRI.HRI_NONE;
    readonly HRI_ABOVE: BarcodeHRI.HRI_ABOVE;
    readonly HRI_BELOW: BarcodeHRI.HRI_BELOW;
    readonly HRI_BOTH: BarcodeHRI.HRI_BOTH;
    readonly BARCODE_UPC_A: BarcodeType.BARCODE_UPC_A;
    readonly BARCODE_UPC_E: BarcodeType.BARCODE_UPC_E;
    readonly BARCODE_EAN13: BarcodeType.BARCODE_EAN13;
    readonly BARCODE_JAN13: BarcodeType.BARCODE_JAN13;
    readonly BARCODE_EAN8: BarcodeType.BARCODE_EAN8;
    readonly BARCODE_JAN8: BarcodeType.BARCODE_JAN8;
    readonly BARCODE_CODE39: BarcodeType.BARCODE_CODE39;
    readonly BARCODE_ITF: BarcodeType.BARCODE_ITF;
    readonly BARCODE_CODABAR: BarcodeType.BARCODE_CODABAR;
    readonly BARCODE_CODE93: BarcodeType.BARCODE_CODE93;
    readonly BARCODE_CODE128: BarcodeType.BARCODE_CODE128;
    readonly BARCODE_CODE128_AUTO: BarcodeType.BARCODE_CODE128_AUTO;
    readonly BARCODE_GS1_128: BarcodeType.BARCODE_GS1_128;
    readonly BARCODE_GS1_DATABAR_OMNIDIRECTIONAL: BarcodeType.BARCODE_GS1_DATABAR_OMNIDIRECTIONAL;
    readonly BARCODE_GS1_DATABAR_TRUNCATED: BarcodeType.BARCODE_GS1_DATABAR_TRUNCATED;
    readonly BARCODE_GS1_DATABAR_LIMITED: BarcodeType.BARCODE_GS1_DATABAR_LIMITED;
    readonly BARCODE_GS1_DATABAR_EXPANDED: BarcodeType.BARCODE_GS1_DATABAR_EXPANDED;
    readonly MODE_MONO: ImageColorModeType.MODE_MONO;
    readonly MODE_GRAY16: ImageColorModeType.MODE_GRAY16;
    readonly MODE_MONO_HIGH_DENSITY: ImageColorModeType.MODE_MONO_HIGH_DENSITY;
    readonly HALFTONE_DITHER: ImageHalftoneType.HALFTONE_DITHER;
    readonly HALFTONE_ERROR_DIFFUSION: ImageHalftoneType.HALFTONE_ERROR_DIFFUSION;
    readonly HALFTONE_THRESHOLD: ImageHalftoneType.HALFTONE_THRESHOLD;
    readonly COMPRESS_DEFLATE: ImageCompressType.COMPRESS_DEFLATE;
    readonly COMPRESS_NONE: ImageCompressType.COMPRESS_NONE;
    readonly COMPRESS_AUTO: ImageCompressType.COMPRESS_AUTO;
    readonly COLOR_NONE: ColorType.COLOR_NONE;
    readonly COLOR_1: ColorType.COLOR_1;
    readonly COLOR_2: ColorType.COLOR_2;
    readonly COLOR_3: ColorType.COLOR_3;
    readonly COLOR_4: ColorType.COLOR_4;
    readonly PRINTER_SETTING_PRINTSPEED1: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED1;
    readonly PRINTER_SETTING_PRINTSPEED2: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED2;
    readonly PRINTER_SETTING_PRINTSPEED3: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED3;
    readonly PRINTER_SETTING_PRINTSPEED4: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED4;
    readonly PRINTER_SETTING_PRINTSPEED5: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED5;
    readonly PRINTER_SETTING_PRINTSPEED6: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED6;
    readonly PRINTER_SETTING_PRINTSPEED7: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED7;
    readonly PRINTER_SETTING_PRINTSPEED8: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED8;
    readonly PRINTER_SETTING_PRINTSPEED9: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED9;
    readonly PRINTER_SETTING_PRINTSPEED10: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED10;
    readonly PRINTER_SETTING_PRINTSPEED11: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED11;
    readonly PRINTER_SETTING_PRINTSPEED12: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED12;
    readonly PRINTER_SETTING_PRINTSPEED13: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED13;
    readonly PRINTER_SETTING_PRINTSPEED14: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED14;
    readonly PRINTER_SETTING_PRINTSPEED15: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED15;
    readonly PRINTER_SETTING_PRINTSPEED16: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED16;
    readonly PRINTER_SETTING_PRINTSPEED17: GetPrinterSettingsPrintSpeedValues.PRINTER_SETTING_PRINTSPEED17;
    readonly PRINTER_SETTING_PRINTDENSITYDIP: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITYDIP;
    readonly PRINTER_SETTING_PRINTDENSITY70: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY70;
    readonly PRINTER_SETTING_PRINTDENSITY75: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY75;
    readonly PRINTER_SETTING_PRINTDENSITY80: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY80;
    readonly PRINTER_SETTING_PRINTDENSITY85: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY85;
    readonly PRINTER_SETTING_PRINTDENSITY90: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY90;
    readonly PRINTER_SETTING_PRINTDENSITY95: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY95;
    readonly PRINTER_SETTING_PRINTDENSITY100: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY100;
    readonly PRINTER_SETTING_PRINTDENSITY105: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY105;
    readonly PRINTER_SETTING_PRINTDENSITY110: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY110;
    readonly PRINTER_SETTING_PRINTDENSITY115: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY115;
    readonly PRINTER_SETTING_PRINTDENSITY120: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY120;
    readonly PRINTER_SETTING_PRINTDENSITY125: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY125;
    readonly PRINTER_SETTING_PRINTDENSITY130: GetPrinterSettingsDensityValues.PRINTER_SETTING_PRINTDENSITY130;
    readonly PRINTER_SETTING_PAPERWIDTH58_0: GetPrinterSettingsPaperWidthValues.PRINTER_SETTING_PAPERWIDTH58_0;
    readonly PRINTER_SETTING_PAPERWIDTH60_0: GetPrinterSettingsPaperWidthValues.PRINTER_SETTING_PAPERWIDTH60_0;
    readonly PRINTER_SETTING_PAPERWIDTH70_0: GetPrinterSettingsPaperWidthValues.PRINTER_SETTING_PAPERWIDTH70_0;
    readonly PRINTER_SETTING_PAPERWIDTH76_0: GetPrinterSettingsPaperWidthValues.PRINTER_SETTING_PAPERWIDTH76_0;
    readonly PRINTER_SETTING_PAPERWIDTH80_0: GetPrinterSettingsPaperWidthValues.PRINTER_SETTING_PAPERWIDTH80_0;
    readonly PRINTER_SETTING_PAPERWIDTH: PrinterGetSettingsType.PRINTER_SETTING_PAPERWIDTH;
    readonly PRINTER_SETTING_PRINTDENSITY: PrinterGetSettingsType.PRINTER_SETTING_PRINTDENSITY;
    readonly PRINTER_SETTING_PRINTSPEED: PrinterGetSettingsType.PRINTER_SETTING_PRINTSPEED;
    readonly CUT_FEED: PrinterAddCutType.CUT_FEED;
    readonly CUT_NO_FEED: PrinterAddCutType.CUT_NO_FEED;
    readonly CUT_RESERVE: PrinterAddCutType.CUT_RESERVE;
    readonly FULL_CUT_FEED: PrinterAddCutType.FULL_CUT_FEED;
    readonly FULL_CUT_NO_FEED: PrinterAddCutType.FULL_CUT_NO_FEED;
    readonly FULL_CUT_RESERVE: PrinterAddCutType.FULL_CUT_RESERVE;
    readonly MODEL_ANK: PrinterModelLang.MODEL_ANK;
    readonly MODEL_CHINESE: PrinterModelLang.MODEL_CHINESE;
    readonly MODEL_TAIWAN: PrinterModelLang.MODEL_TAIWAN;
    readonly MODEL_KOREAN: PrinterModelLang.MODEL_KOREAN;
    readonly MODEL_THAI: PrinterModelLang.MODEL_THAI;
    readonly MODEL_SOUTHASIA: PrinterModelLang.MODEL_SOUTHASIA;
};
export { PrinterModelLang, PrinterGetSettingsType, GetPrinterSettingsDensityValues, GetPrinterSettingsPaperWidthValues, GetPrinterSettingsPrintSpeedValues, PrinterAddCutType, PrinterErrorResult, PrinterErrorCodeResult, ColorType, ImageCompressType, ImageHalftoneType, ImageColorModeType, CommonParams, BarcodeType, BarcodeHRI, FontType, SymbolType, SymbolLevel, PrinterAddPulseDrawerType, PrinterAddPulseTimeType, TextAlignType, PrinterPaperStatus, PrinterPanelSwitchStatus, PrinterDrawerStatus, PrinterErrorStatus, PrinterAutoRecoverErrorStatus, PrinterBatteryLevelStatus, PrinterRemovalWaitingStatus, PrinterPaperTakenSensorStatus, PrinterUnrecoverErrorStatus, TextLangType, };
//# sourceMappingURL=index.d.ts.map